@@ -8,7 +8,17 @@ import MessageDto
 class MessageController:
 
     @ControllerMethod(url = '/',
-        apiKeyRequired = [AccessDomain.API, AccessDomain.USER],
+        apiKeyRequired = [AccessDomain.ADMIN],
+        requestParamClass = [MessageDto.MessageQueryRequestDto],
+        responseClass = [MessageDto.MessageCreationResponseDto]
+        , logRequest = True
+        , logResponse = True
+    )
+    def get(self, params=None):
+        return self.service.message.findByQuery(params), HttpStatus.ACCEPTED
+
+    @ControllerMethod(url = '/',
+        apiKeyRequired = [AccessDomain.API, AccessDomain.USER, AccessDomain.ADMIN],
         requestClass = [MessageDto.MessageRequestDto],
         responseClass = [MessageDto.MessageCreationResponseDto]
         , logRequest = True
