@@ -1,5 +1,4 @@
 import json
-from flask import copy_current_request_context
 
 from python_helper import Constant as c
 from python_helper import ReflectionHelper, ObjectHelper, log, Function, StringHelper
@@ -178,6 +177,7 @@ def MessageListenerMethod(
                 )
 
                 ###- only works if it's declared within a context
+                # from flask import copy_current_request_context
                 # if resourceInstanceMethodRunInAThread:
                 #     ###- https://flask.palletsprojects.com/en/2.1.x/api/#flask.copy_current_request_context
                 #     @copy_current_request_context
